@@ -45,8 +45,10 @@ from braintree.payment_method_nonce import PaymentMethodNonce
 from braintree.paypal_account import PayPalAccount
 from braintree.plan import Plan
 from braintree.plan_gateway import PlanGateway
+from braintree.processor_response_types import ProcessorResponseTypes
 from braintree.resource_collection import ResourceCollection
 from braintree.risk_data import RiskData
+from braintree.samsung_pay_card import SamsungPayCard
 from braintree.search import Search
 from braintree.settlement_batch_summary import SettlementBatchSummary
 from braintree.signature_service import SignatureService
